==> knotes-17.04.2.tar.xz: knotes-17.04.2/src/dialog/knotedeleteselectednotesdialog.h <==
/*
   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/
#ifndef KNOTEDELETESELECTEDNOTESDIALOG_H
#define KNOTEDELETESELECTEDNOTESDIALOG_H

#include <QDialog>
#include <AkonadiCore/Item>
class QPushButton;
namespace NoteShared
{
class NoteListWidget;
}

class KNoteDeleteSelectedNotesDialog : public QDialog
{
    Q_OBJECT
public:
    explicit KNoteDeleteSelectedNotesDialog(QWidget *parent = nullptr);
    ~KNoteDeleteSelectedNotesDialog();

    void setNotes(const Akonadi::Item::List &notes);

    Akonadi::Item::List selectedNotes() const;

private Q_SLOTS:
    void slotDeleteNoteSelectionChanged();
private:
    void readConfig();
    void writeConfig();
    NoteShared::NoteListWidget *mNoteList;
    QPushButton *mOkButton;
};

#endif // KNOTEDELETESELECTEDNOTESDIALOG_H

==> knotes_20.08.3.orig.tar.xz: knotes-20.08.3/src/dialog/knotedeleteselectednotesdialog.h <==
/*
   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/
#ifndef KNOTEDELETESELECTEDNOTESDIALOG_H
#define KNOTEDELETESELECTEDNOTESDIALOG_H

#include <QDialog>
#include <AkonadiCore/Item>
class QPushButton;
namespace NoteShared {
class NoteListWidget;
}

class KNoteDeleteSelectedNotesDialog : public QDialog
{
    Q_OBJECT
public:
    explicit KNoteDeleteSelectedNotesDialog(QWidget *parent = nullptr);
    ~KNoteDeleteSelectedNotesDialog();

    void setNotes(const Akonadi::Item::List &notes);

    Akonadi::Item::List selectedNotes() const;

private Q_SLOTS:
    void slotDeleteNoteSelectionChanged();
private:
    void readConfig();
    void writeConfig();
    NoteShared::NoteListWidget *mNoteList = nullptr;
    QPushButton *mOkButton = nullptr;
};

#endif // KNOTEDELETESELECTEDNOTESDIALOG_H
